==> libcamera-docs-0.4.0-1-aarch64.pkg.tar.xz: usr/share/doc/libcamera/internal-api-html/search/functions_16.js <==
var searchData=
[
  ['v4l2buffercache_0',['V4L2BufferCache',['../classlibcamera_1_1V4L2BufferCache.html#a2e85353e7d8aaeb616be5dd642830401',1,'libcamera::V4L2BufferCache::V4L2BufferCache(unsigned int numEntries)'],['../classlibcamera_1_1V4L2BufferCache.html#abf2d3fdf1877c5db0ea73a4ccc17ed46',1,'libcamera::V4L2BufferCache::V4L2BufferCache(const std::vector&lt; std::unique_ptr&lt; FrameBuffer &gt; &gt; &amp;buffers)']]],
  ['v4l2device_1',['V4L2Device',['../classlibcamera_1_1V4L2Device.html#af2c3423ffe8a3333ea7c82018b49844d',1,'libcamera::V4L2Device']]],
  ['v4l2m2mconverter_2',['V4L2M2MConverter',['../classlibcamera_1_1V4L2M2MConverter.html#a29aeac44dbed3e1c76d4daad84038dac',1,'libcamera::V4L2M2MConverter']]],
  ['v4l2m2mdevice_3',['V4L2M2MDevice',['../classlibcamera_1_1V4L2M2MDevice.html#aada8b048cfaaefb7da7347e101dfff7f',1,'libcamera::V4L2M2MDevice']]],
  ['v4l2pixelformat_4',['V4L2PixelFormat',['../classlibcamera_1_1V4L2PixelFormat.html#ac38e458d9f1afd50a057a96c4d2a8132',1,'libcamera::V4L2PixelFormat::V4L2PixelFormat()'],['../classlibcamera_1_1V4L2PixelFormat.html#a6efc742cb5c93d7ac1c67f87b810b56b',1,'libcamera::V4L2PixelFormat::V4L2PixelFormat(uint32_t fourcc)']]],
  ['v4l2subdevice_5',['V4L2Subdevice',['../classlibcamera_1_1V4L2Subdevice.html#aded4791bb9d9a977f33417b19590d1af',1,'libcamera::V4L2Subdevice']]],
  ['v4l2videodevice_6',['V4L2VideoDevice',['../classlibcamera_1_1V4L2VideoDevice.html#a612aca15d344aa5c59f9f90d4cb09e57',1,'libcamera::V4L2VideoDevice::V4L2VideoDevice(const std::string &amp;deviceNode)'],['../classlibcamera_1_1V4L2VideoDevice.html#a78fd4cc6f5d062c2392715ae72519377',1,'libcamera::V4L2VideoDevice::V4L2VideoDevice(const MediaEntity *entity)']]],
  ['validate_7',['validate',['../classlibcamera_1_1CameraConfiguration.html#aae311c7b13dacce196b6c82a1b67bba9',1,'libcamera::CameraConfiguration::validate()'],['../classlibcamera_1_1CameraControlValidator.html#a71b33785a52fcdb71b31bc2286ea412d',1,'libcamera::CameraControlValidator::validate()'],['../classlibcamera_1_1ControlValidator.html#a30f2d3d577428bcd03614f441506a79d',1,'libcamera::ControlValidator::validate()']]],
  ['validatecolorspaces_8',['validateColorSpaces',['../classlibcamera_1_1CameraConfiguration.html#a197791527afd705483a0b6236e32c6b7',1,'libcamera::CameraConfiguration']]],
  ['validateoutput_9',['validateOutput',['../classlibcamera_1_1Converter.html#aff773eb476c5d9941734e2ce21fcfd13',1,'libcamera::Converter::validateOutput()'],['../classlibcamera_1_1V4L2M2MConverter.html#ac8a7bc36b0aac28b810c45929abcd522',1,'libcamera::V4L2M2MConverter::validateOutput()']]],
  ['validator_10',['validator',['../classlibcamera_1_1Camera_1_1Private.html#af42d5796d0bc8e36ff0cd5f0e0eb7443',1,'libcamera::Camera::Private']]],
  ['values_11',['values',['../classlibcamera_1_1ControlInfo.html#a1ce70ac404f45eaf9bb0386918aaedca',1,'libcamera::ControlInfo']]],
  ['vector_12',['Vector',['../classlibcamera_1_1ipa_1_1Vector.html#a568fba2456dfadd26222457454216407',1,'libcamera::ipa::Vector::Vector()=default'],['../classlibcamera_1_1ipa_1_1Vector.html#aabec9e05a1a46374c8e51a1869b09bcc',1,'libcamera::ipa::Vector::Vector(T scalar)'],['../classlibcamera_1_1ipa_1_1Vector.html#a93f8b9fa92d7cce35697be890e8a0cf0',1,'libcamera::ipa::Vector::Vector(const std::array&lt; T, Rows &gt; &amp;data)']]],
  ['vendor_13',['vendor',['../classlibcamera_1_1ControlId.html#aba34f493d8313c60930c9d9cce61922c',1,'libcamera::ControlId']]],
  ['verify_14',['verify',['../classlibcamera_1_1PubKey.html#a959683b12bed8b7ec178c8b0b72fe6c5',1,'libcamera::PubKey']]],
  ['version_15',['version',['../classlibcamera_1_1CameraManager.html#a7a9c0aefeac0ff1e3a42da3072ab0a97',1,'libcamera::CameraManager::version()'],['../classlibcamera_1_1MediaDevice.html#af335184ee6174ea68747d32955d6f9c8',1,'libcamera::MediaDevice::version()']]]
];

==> libcamera-docs-0.5.1-2-aarch64.pkg.tar.xz: usr/share/doc/libcamera/internal-api-html/search/functions_16.js <==
var searchData=
[
  ['v4l2buffercache_0',['V4L2BufferCache',['../classlibcamera_1_1V4L2BufferCache.html#a2e85353e7d8aaeb616be5dd642830401',1,'libcamera::V4L2BufferCache::V4L2BufferCache(unsigned int numEntries)'],['../classlibcamera_1_1V4L2BufferCache.html#abf2d3fdf1877c5db0ea73a4ccc17ed46',1,'libcamera::V4L2BufferCache::V4L2BufferCache(const std::vector&lt; std::unique_ptr&lt; FrameBuffer &gt; &gt; &amp;buffers)']]],
  ['v4l2device_1',['V4L2Device',['../classlibcamera_1_1V4L2Device.html#af2c3423ffe8a3333ea7c82018b49844d',1,'libcamera::V4L2Device']]],
  ['v4l2m2mconverter_2',['V4L2M2MConverter',['../classlibcamera_1_1V4L2M2MConverter.html#a29aeac44dbed3e1c76d4daad84038dac',1,'libcamera::V4L2M2MConverter']]],
  ['v4l2m2mdevice_3',['V4L2M2MDevice',['../classlibcamera_1_1V4L2M2MDevice.html#aada8b048cfaaefb7da7347e101dfff7f',1,'libcamera::V4L2M2MDevice']]],
  ['v4l2pixelformat_4',['V4L2PixelFormat',['../classlibcamera_1_1V4L2PixelFormat.html#ac38e458d9f1afd50a057a96c4d2a8132',1,'libcamera::V4L2PixelFormat::V4L2PixelFormat()'],['../classlibcamera_1_1V4L2PixelFormat.html#a6efc742cb5c93d7ac1c67f87b810b56b',1,'libcamera::V4L2PixelFormat::V4L2PixelFormat(uint32_t fourcc)']]],
  ['v4l2subdevice_5',['V4L2Subdevice',['../classlibcamera_1_1V4L2Subdevice.html#aded4791bb9d9a977f33417b19590d1af',1,'libcamera::V4L2Subdevice']]],
  ['v4l2videodevice_6',['V4L2VideoDevice',['../classlibcamera_1_1V4L2VideoDevice.html#a612aca15d344aa5c59f9f90d4cb09e57',1,'libcamera::V4L2VideoDevice::V4L2VideoDevice(const std::string &amp;deviceNode)'],['../classlibcamera_1_1V4L2VideoDevice.html#a78fd4cc6f5d062c2392715ae72519377',1,'libcamera::V4L2VideoDevice::V4L2VideoDevice(const MediaEntity *entity)']]],
  ['validate_7',['validate',['../classlibcamera_1_1CameraConfiguration.html#aae311c7b13dacce196b6c82a1b67bba9',1,'libcamera::CameraConfiguration::validate()'],['../classlibcamera_1_1CameraControlValidator.html#a71b33785a52fcdb71b31bc2286ea412d',1,'libcamera::CameraControlValidator::validate()'],['../classlibcamera_1_1ControlValidator.html#a30f2d3d577428bcd03614f441506a79d',1,'libcamera::ControlValidator::validate()']]],
  ['validatecolorspaces_8',['validateColorSpaces',['../classlibcamera_1_1CameraConfiguration.html#a197791527afd705483a0b6236e32c6b7',1,'libcamera::CameraConfiguration']]],
  ['validateoutput_9',['validateOutput',['../classlibcamera_1_1Converter.html#aff773eb476c5d9941734e2ce21fcfd13',1,'libcamera::Converter::validateOutput()'],['../classlibcamera_1_1V4L2M2MConverter.html#ac8a7bc36b0aac28b810c45929abcd522',1,'libcamera::V4L2M2MConverter::validateOutput()']]],
  ['validator_10',['validator',['../classlibcamera_1_1Camera_1_1Private.html#af42d5796d0bc8e36ff0cd5f0e0eb7443',1,'libcamera::Camera::Private']]],
  ['values_11',['values',['../classlibcamera_1_1ControlInfo.html#a1ce70ac404f45eaf9bb0386918aaedca',1,'libcamera::ControlInfo']]],
  ['vector_12',['Vector',['../classlibcamera_1_1Vector.html#a98073779cde78cde03da4f575fc56257',1,'libcamera::Vector::Vector()=default'],['../classlibcamera_1_1Vector.html#a607fb9af7a28b1427d6d4443a52a07c7',1,'libcamera::Vector::Vector(T scalar)'],['../classlibcamera_1_1Vector.html#a2f8ddd4a967c819967ca20ded11b460c',1,'libcamera::Vector::Vector(const std::array&lt; T, Rows &gt; &amp;data)'],['../classlibcamera_1_1Vector.html#adfc2ffe105653a9ece586c8551bbd724',1,'libcamera::Vector::Vector(const Span&lt; const T, Rows &gt; data)']]],
  ['vendor_13',['vendor',['../classlibcamera_1_1ControlId.html#aba34f493d8313c60930c9d9cce61922c',1,'libcamera::ControlId']]],
  ['verify_14',['verify',['../classlibcamera_1_1PubKey.html#a959683b12bed8b7ec178c8b0b72fe6c5',1,'libcamera::PubKey']]],
  ['version_15',['version',['../classlibcamera_1_1CameraManager.html#a7a9c0aefeac0ff1e3a42da3072ab0a97',1,'libcamera::CameraManager::version()'],['../classlibcamera_1_1MediaDevice.html#af335184ee6174ea68747d32955d6f9c8',1,'libcamera::MediaDevice::version()']]]
];
